@@ -1,14 +1,16 @@
-import os
-from logging import Logger, INFO
 import json
-from typing import Dict, List
-import urllib.request
+import os
 import re
+import urllib.request
+from logging import INFO, Logger
+from typing import Dict, List
+from urllib.parse import urljoin
 
 import toml
 import yaml
 from deepmerge import always_merger
 
+
 class Config:
     """
     This class emulates the Spring Boot functionality.
@@ -68,13 +70,13 @@ class Config:
             # check for expected config files if location is a path
             elif os.path.isdir(location):
                 for extension in Config.allowed_extensions:
-                    filepath = location + f"/application.{extension}"
+                    filepath = os.path.join(location, f"application.{extension}")
                     if os.path.isfile(filepath):
                         self.logger.debug(f'Parse config {filepath}')
                         self._parse_config_file(filepath)
                     #check for each profile name if a config file exists
                     for profile in self.get_profiles():
-                        filepath = location + f"/application-{profile}.{extension}"
+                        filepath = os.path.join(location, f"application-{profile}.{extension}")
                         if os.path.isfile(filepath):
                             self.logger.debug(f'Parse config {filepath}')
                             self._parse_config_file(filepath)
@@ -221,9 +223,9 @@ class Config:
             raise ValueError('If spring.cloud.config.uri is set spring.application.name is required')
 
         if label:
-            address = f'{uri}/{label}/{app_name}-{profiles}.json'
+            address = urljoin(uri, f"{label}/{app_name}-{profiles}.json")
         else:
-            address = f'{uri}/{app_name}-{profiles}.json'
+            address = urljoin(uri, f"{app_name}-{profiles}.json")
 
         self.logger.info(
             f"Try to load configuration from spring cloud config server at {address}")
@@ -231,9 +233,6 @@ class Config:
         try:
             with urllib.request.urlopen(address) as response:
                 config = json.loads(response.read())
-                # Keys to lower case
-                #config = self._make_lowercase(config)
-
                 self._config = always_merger.merge(self._config, config)
 
         except urllib.error.URLError as e:
@@ -247,7 +246,9 @@ class Config:
                 ret[k] = self.replace_variables(v)
             return ret
         elif isinstance(obj, str):
-            for m in re.finditer('\$\{(?P<key1>[^\}]+):(?P<fallback>[^}]+)\}|\$\{(?P<key2>[^\}]+)\}', obj):
+            regex = r'[$]{(?P<key1>[^}]+):(?P<fallback>[^}]+)}|[$]{(?P<key2>[^}]+)}'
+            result = obj
+            for m in re.finditer(regex, obj):
                 match = m.group(0)
                 key = m.group('key1') if m.group('key1') else m.group('key2')
                 fallback = m.group('fallback')
@@ -258,10 +259,14 @@ class Config:
                         replacement = fallback
                     else:
                         replacement = ''
-                obj = obj.replace(match, replacement, 1)
-
-
-            return obj
+                
+                if match == obj: 
+                    result = replacement
+                else:
+                    if not isinstance(replacement, str):
+                        replacement = str(replacement)
+                    result = result.replace(match, replacement, 1)
+            return result
         elif hasattr(obj,'__iter__'):
             ret = []
             for item in obj:
@@ -271,6 +276,6 @@ class Config:
             return obj
 
     def to_camel_case(self, snake_str: str):
-        components = snake_str.split('_')
+        components = snake_str.lower().split('_')
         return components[0] + ''.join(x.title() for x in components[1:])
                     
\ No newline at end of file
